summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorHugo Landau <hlandau@openssl.org>2024-02-02 09:14:26 +0000
committerHugo Landau <hlandau@openssl.org>2024-02-08 16:50:01 +0000
commit37228ded0faab6c10f7438f812ce611e0a41830b (patch)
tree9b4d153a0c8fe0ebdb524c2e010c81ad35904565 /test
parent07e66f3c3d758619d8594e51afea80d7d23908db (diff)
Fixup multistream test
Reviewed-by: Neil Horman <nhorman@openssl.org> Reviewed-by: Matt Caswell <matt@openssl.org> Reviewed-by: Tomas Mraz <tomas@openssl.org> (Merged from https://github.com/openssl/openssl/pull/23360)
Diffstat (limited to 'test')
-rw-r--r--test/quic_multistream_test.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/test/quic_multistream_test.c b/test/quic_multistream_test.c
index 4ae7ae976a..9b97257227 100644
--- a/test/quic_multistream_test.c
+++ b/test/quic_multistream_test.c
@@ -5342,7 +5342,7 @@ static const struct script_op script_83[] = {
OP_END
};
/* 83. Test query of available streams */
static int check_avail_streams(struct helper *h, struct helper_local *hl)
{
uint64_t v = 0;
@@ -5374,7 +5374,7 @@ static int check_avail_streams(struct helper *h, struct helper_local *hl)
return 1;
}
-static const struct script_op script_83[] = {
+static const struct script_op script_84[] = {
OP_C_SET_ALPN ("ossltest")
OP_C_CONNECT_WAIT ()
@@ -5504,10 +5504,11 @@ static const struct script_op *const scripts[] = {
script_77,
script_78,
script_79,
- script_80
+ script_80,
script_81,
script_82,
- script_83
+ script_83,
+ script_84
};
static int test_script(int idx)
@@ -5342,7 +5342,7 @@ static const struct script_op script_83[] = {
OP_END
};
-/* 83. Test query of available streams */
+/* 84. Test query of available streams */
static int check_avail_streams(struct helper *h, struct helper_local *hl)
{